<?php

namespace Chemtech\Test\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Chemtech\Test\Events\ConditionWorkflow as ConditionWorkflowEvent;
use Chemtech\Test\Notifications\ConditionWorkflow as ConditionWorkflowNotification;
use Litepie\Actions\Concerns\AsAction;

class ConditionWorkflow
{
    use AsAction;

    private $allowedTransitions = [
        'before' => [],
        'after' => ['publish', 'submit', 'approve'],
    ];

    public function handle(ConditionWorkflowEvent $event)
    {
        $function = Str::camel($event->transition);
        return $this->$function($event);
    }

    /**
     * Sends a notification to the client when the $condition is submitted.
     *
     * @param ConditionWorkflowEvent $event The event object.
     * @return void
     */
    public function submit(ConditionWorkflowEvent $event)
    {
        $client = $event->condition->client;
        Notification::send($client, new ConditionWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $condition is published.
     *
     * @param ConditionWorkflowEvent $event The event object.
     * @return void
     */
    public function publish(ConditionWorkflowEvent $event)
    {
        $client = $event->condition->client;
        Notification::send($client, new ConditionWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $condition is approved.
     *
     * @param ConditionWorkflowEvent $event The event object.
     * @return void
     */
    public function approve(ConditionWorkflowEvent $event)
    {
        $client = $event->condition->client;
        Notification::send($client, new ConditionWorkflowNotification($event));
    }

    /**
     * Handles the $condition workflow event as a listener.
     *
     * @param ConditionWorkflowEvent $event The event object.
     * @return void
     */
    public function asListener(ConditionWorkflowEvent $event)
    {
        if (($event->when == 'before' &&
            in_array($event->transition, $this->allowedTransitions['before']) ||
            $event->when == 'after' &&
            in_array($event->transition, $this->allowedTransitions['after']))
        ) {
            return $this->handle($event);
        }
    }
}
