<?php

namespace Chemtech\Test\Policies;

use Illuminate\Foundation\Auth\User as Authenticatable;
use Chemtech\Test\Models\Condition;

class ConditionPolicy
{


    /**
     * Determine if the given user can view the condition.
     *
     * @param Authenticatable $user
     * @param Condition $condition
     *
     * @return bool
     */
    public function view(Authenticatable $user, Condition $condition)
    {
        if ($authUser->canDo('test.condition.view') && $authUser->isAdmin() || $user->isClient()) {
            return true;
        }

        return $condition->is_owner;
    }

    /**
     * Determine if the given user can create a condition.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function create(Authenticatable $user)
    {
        return  $authUser->canDo('test.condition.create');
    }

    /**
     * Determine if the given user can update the given condition.
     *
     * @param Authenticatable $user
     * @param Condition $condition
     *
     * @return bool
     */
    public function update(Authenticatable $user, Condition $condition)
    {
        if ($user->canDo('test.condition.edit') && $user->isAdmin()) {
            return true;
        }

        return $condition->is_owner;
    }

    /**
     * Determine if the given user can delete the given condition.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function destroy(Authenticatable $user, Condition $condition)
    {
        return $condition->is_owner;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
